@@ -66,6 +66,26 @@ var ScrapBookBrowserOverlay = {
 			menubar.appendChild(button);
 			menubar.removeChild(menu);
 		}
+		var key = ScrapBookUtils.getPref("key.menubar");
+		if (key.length == 1) {
+			var elt = document.getElementById("ScrapBookMenu");
+			elt.setAttribute("accesskey", key);
+		}
+		var keyMap = {
+			"key.sidebar"    : "key_openScrapBookSidebar",
+			"key.save"       : "key_ScrapBookCapture",
+			"key.saveAs"     : "key_ScrapBookCaptureAs",
+			"key.saveAllTabs": "key_ScrapBookSaveAllTabs",
+			"key.bookmark"   : "key_BookmarkWithScrapBook",
+		};
+		for (let [pref, id] in Iterator(keyMap)) {
+			var key = ScrapBookUtils.getPref(pref);
+			var elt = document.getElementById(id);
+			if (key.length == 1)
+				elt.setAttribute("key", key);
+			else
+				elt.parentNode.removeChild(elt);
+		}
 	},
 
 	destroy: function()
@@ -354,6 +374,7 @@ var ScrapBookBrowserOverlay = {
 	{
 		if (event.originalTarget.localName == "menu" || event.button != 1)
 			return;
+		document.getElementById("contentAreaContextMenu").hidePopup();
 		switch (aFlag) {
 			case 1 : this.execCapture(1, true, true , event.originalTarget.id); break;
 			case 3 : this.execCapture(2, false,true , event.originalTarget.id); break;
