@@ -14,7 +14,6 @@ var sbContentSaver = {
 	frameNumber  : 0,
 	selection    : null,
 	linkURLs     : [],
-	_fxVer35     : null,
 
 
 
@@ -30,11 +29,6 @@ var sbContentSaver = {
 
 	init : function(aPresetData)
 	{
-		if (this._fxVer35 === null) {
-			var verComp = Cc["@mozilla.org/xpcom/version-comparator;1"].
-			              getService(Ci.nsIVersionComparator);
-			this._fxVer35 = verComp.compare(Application.version, "3.5") >= 0;
-		}
 		this.item = ScrapBookData.newItem();
 		this.name = "index";
 		this.favicon = null;
@@ -61,7 +55,7 @@ var sbContentSaver = {
 		this.item.source = aRootWindow.location.href;
 		if ( "gBrowser" in window && aRootWindow == gBrowser.contentWindow )
 		{
-			this.item.icon = gBrowser.mCurrentBrowser.mIconURL;
+			this.item.icon = gBrowser.mCurrentTab.image;
 		}
 		this.frameList = this.flattenFrames(aRootWindow);
 		var titles = aRootWindow.document.title ? [aRootWindow.document.title] : [this.item.source];
@@ -525,6 +519,10 @@ var sbContentSaver = {
 				pre.appendChild(aNode.firstChild);
 				aNode.parentNode.replaceChild(pre, aNode);
 				break;
+			case "source": 
+				if (aNode.src)
+					aNode.setAttribute("src", aNode.src);
+				break;
 		}
 		if ( !this.option["styles"] )
 		{
@@ -616,17 +614,14 @@ var sbContentSaver = {
 			aCSShref = this.refURLObj.spec;
 		}
 		if ( !aCSStext ) return;
-		if (this._fxVer35) {
-			if (/^([^\{]+)\s+\{/.test(aCSStext)) {
-				var selectors = RegExp.$1.trim();
-				selectors = selectors.replace(/:[a-z-]+/g, "");
-				try {
-					if (!aDocument.querySelector(selectors))
-						return;
-				}
-				catch (ex) {
-				}
+		if (/^([^\{]+)\s+\{/.test(aCSStext)) {
+			var selectors = RegExp.$1.trim();
+			selectors = selectors.replace(/:[a-z-]+/g, "");
+			try {
+				if (!aDocument.querySelector(selectors))
+					return;
 			}
+			catch (ex) {}
 		}
 		var re = new RegExp(/ url\(([^\'\)\s]+)\)/);
 		var i = 0;
