@@ -1,5 +1,3 @@
-pref("extensions.{53A03D43-5363-4669-8190-99061B2DEBA5}.description", "chrome://scrapbook/locale/about.properties");
-
 pref("scrapbook.ui.contextMenu", true);
 pref("scrapbook.ui.contextSubMenu", false);
 pref("scrapbook.ui.bookmarkMenu", true);
@@ -28,4 +26,9 @@ pref("scrapbook.tree.autoCollapse", false);
 pref("scrapbook.confirmDelete", true);
 pref("scrapbook.showDetailOnDrop", false);
 pref("scrapbook.notifyOnComplete", true);
-
+pref("scrapbook.key.menubar", "C");
+pref("scrapbook.key.sidebar", "K");
+pref("scrapbook.key.save", "");
+pref("scrapbook.key.saveAs", "");
+pref("scrapbook.key.saveAllTabs", "");
+pref("scrapbook.key.bookmark", "");
